@@ -8,9 +8,9 @@ __all__ = ["Configuration", "ConfigurationParser"]
 import datetime
 import pathlib
 
-import longling.ML.PytorchHelper.tore.parser as parser
 from longling import path_append
 from longling.ML.PytorchHelper.tore.parser import eval_var
+from longling.ML.PytorchHelper.tore import parser
 from longling.lib.parser import var2exp
 from longling.lib.utilog import config_logging, LogLevel
 
@@ -103,7 +103,7 @@ class Configuration(parser.Configuration):
 
         params = self.class_var
         if params_json:
-            params.update(self.load_cfg(params_path=params_json))
+            params.update(self.load_cfg(cfg_path=params_json))
         params.update(**kwargs)
 
         # path_override_check
@@ -141,7 +141,6 @@ class Configuration(parser.Configuration):
             setattr(self, _dir, eval(exp))
 
         _vars = [
-            # "ctx"
         ]
         for _var in _vars:
             if _var in kwargs:
@@ -157,9 +156,9 @@ class Configuration(parser.Configuration):
             self.model_dir, "configuration.json", to_str=True
         )
 
-    def dump(self, cfg_path=None, override=False):
+    def dump(self, cfg_path: str, override=True, file_format=None):
         cfg_path = self.cfg_path if cfg_path is None else cfg_path
-        super(Configuration, self).dump(cfg_path, override)
+        super(Configuration, self).dump(cfg_path, override, file_format=file_format)
 
     @staticmethod
     def load(cfg_path, **kwargs):
