@@ -11,6 +11,7 @@ from longling import path_append
 from longling.lib import parser
 from longling.lib.parser import var2exp
 from longling.lib.utilog import config_logging, LogLevel
+from ..const import CFG_JSON, RESULT_JSON
 
 
 class Configuration(parser.Configuration):
@@ -56,19 +57,41 @@ class Configuration(parser.Configuration):
         Notes
         -----
         Developers modifying this code should simultaneously modify the relevant codes in glue and tore
+
+        Examples
+        --------
+        >>> cfg = Configuration(epoch=5)
+        >>> cfg["epoch"]
+        5
+        >>> cfg   # doctest: +ELLIPSIS
+        logger: <Logger MLModel (INFO)>
+        model_name: MLModel
+        root: ./
+        ...
         """
-        super(Configuration, self).__init__(
-            logger=config_logging(
-                logger=self.model_name,
-                console_log_level=LogLevel.INFO
-            )
-        )
+        super(Configuration, self).__init__()
 
         params = self.class_var
         if params_path:
             params.update(self.load_cfg(cfg_path=params_path, **(params_kwargs if params_kwargs else {})))
         params.update(**kwargs)
 
+        self.validation_result_file = None
+        self.cfg_path = None
+
+        self._update(**params)
+
+    def _update(self, **kwargs):
+        params = kwargs
+
+        params["logger"] = params.pop(
+            "logger",
+            config_logging(
+                logger=params.get("model_name", self.model_name),
+                console_log_level="info"
+            )
+        )
+
         for key in params:
             if key.endswith("_params") and key + "_update" in params:
                 params[key].update(params[key + "_update"])
@@ -108,10 +131,10 @@ class Configuration(parser.Configuration):
             setattr(self, _dir, eval(exp))
 
         self.validation_result_file = path_append(
-            self.model_dir, "result.json", to_str=True
+            self.model_dir, RESULT_JSON, to_str=True
         )
         self.cfg_path = path_append(
-            self.model_dir, "configuration.json", to_str=True
+            self.model_dir, CFG_JSON, to_str=True
         )
 
     def dump(self, cfg_path=None, override=True, file_format=None):
