@@ -11,9 +11,8 @@ import logging
 import os
 import re
 import sys
-from collections import Iterable
 from copy import deepcopy
-from typing import List, Dict
+from typing import List, Dict, Iterable
 
 import toml
 import yaml
@@ -228,7 +227,7 @@ class Configuration(object):
     Examples
     --------
     >>> c = Configuration(a=1, b="example", c=[0,2], d={"a1": 3})
-    >>> c.parsable_var
+    >>> c.instance_var
     {'a': 1, 'b': 'example', 'c': [0, 2], 'd': {'a1': 3}}
     >>> c.default_file_format()
     'json'
@@ -238,6 +237,9 @@ class Configuration(object):
     True
     >>> c.get("e", 0)
     0
+    >>> c.update(e=2)
+    >>> c["e"]
+    2
     """
 
     def __init__(self, logger=logging, **kwargs):
@@ -250,6 +252,18 @@ class Configuration(object):
             # all class variables will be contained in instance variables
             setattr(self, "%s" % param, value)
 
+    def deep_update(self, **kwargs):
+        for param, value in kwargs.items():
+            setattr(self, "%s" % param, value)
+
+    def _update(self, **kwargs):
+        self.deep_update(**kwargs)
+
+    def update(self, **kwargs):
+        params = self.instance_var
+        params.update(**kwargs)
+        self._update(**params)
+
     @classmethod
     def vars(cls):
         # todo: check why when deepcopy is missed, two instance will have same id for class_var
@@ -291,6 +305,14 @@ class Configuration(object):
             dump_parse_functions=None,
         )
 
+    @property
+    def instance_var(self):
+        return get_parsable_var(
+            self,
+            parse_exclude=None,
+            dump_parse_functions=None,
+        )
+
     @classmethod
     def load_parse_function(cls):
         return None
@@ -394,7 +416,8 @@ class Configuration(object):
             所有非参变量
         """
         return CLASS_EXCLUDE_NAMES | {
-            'class_var', 'parsable_var', 'items', 'load', 'dump', 'help_info', 'get'
+            'class_var', 'parsable_var', 'instance_var', 'items', 'load', 'dump', 'help_info', 'get', 'update',
+            'deep_update'
         } | cls.run_time_variables()
 
     @classmethod
@@ -687,7 +710,7 @@ class ConfigurationParser(argparse.ArgumentParser):
     @staticmethod
     def parse(arguments):
         """参数后解析"""
-        arguments = vars(arguments)
+        arguments = vars(arguments) if not isinstance(arguments, dict) else arguments
         args_dict = dict()
         for k, v in arguments.items():
             if k == "kwargs" and v:
